Crate splashsurf_lib
source ·Expand description
Library for surface reconstruction of SPH particle data using marching cubes.
Entry points are the reconstruct_surface or reconstruct_surface_inplace functions.
Feature flags
The following features are all non-default features to reduce the amount of additional dependencies.
vtk_extras: Enables helper functions and trait implementations to export meshes usingvtkio. In particular it addsFromimpls for the mesh types used by this crate to convert them tovtkio::model::UnstructuredGridPieceandvtkio::model::DataSettypes. If the feature is enabled, The crate exposes itsvtkiodependency assplashsurflib::vtkio.io: Enables theiomodule, containing functions to load and store particle and mesh files from various file formats, e.g.VTK,OBJ,BGEOetc. This feature implies thevtk_extrasfeature. It is disabled by default because a pure “online” surface reconstruction might not need any file IO. The feature adds several dependencies to support the file formats.profiling: Enables profiling of internal functions. The resulting data can be displayed using the functions from theprofilingmodule of this crate. Furthermore, it exposes theprofilemacro that can be used e.g. by binary crates calling into this library to add their own profiling scopes to the measurements. If this features is not enabled, the macro will just expend to a no-op and remove the (small) performance overhead of the profiling.
Re-exports
pub use crate::density_map::DensityMap;pub use crate::octree::SubdivisionCriterion;pub use crate::uniform_grid::UniformGrid;pub use nalgebra;pub use vtkio;
Modules
- Computation of sparse density maps (evaluation of particle densities and mapping onto sparse grids)
- Generic tree visitation functions that can be used with tree-like structures
- Basic implementation of a half-edge based triangle mesh
- io
ioConvenience functions for importing particle data and meshes from various file formats - SPH kernel function implementations
- Triangulation of
DensityMaps using marching cubes - Basic mesh types used by the library and implementation of VTK export
- Simple neighborhood search based on spatial hashing
- Octree for spatially partitioning particle sets
- Functions for post-processing of surface meshes (decimation, smoothing, etc.)
- profiling
profilingImplementation details for theprofilemacro - Functions for interpolating quantities (e.g. normals, scalar fields) by evaluating SPH sums
- Helper types for cartesian coordinate system topology
- Helper types for the implicit background grid used for marching cubes
Macros
- profile
profilingCreates a scope for profiling
Structs
- Type representing an axis aligned bounding box in arbitrary dimensions
- Parameters for the uniform grid-based spatial decomposition
- Parameters for the octree-based spatial decomposition
- Parameters for the surface reconstruction
- Result data returned when the surface reconstruction was successful
Enums
- Available strategies for the computation of the particle densities
- Error type returned when the surface reconstruction fails
- Approach used for spatial decomposition of the surface reconstruction and its parameters
Traits
- Trait that has to be implemented for types to be used as background grid cell indices in the context of the library
- Trait that has to be implemented for types to be used as floating points values in the context of the library (e.g. for coordinates, density values)
- Trait for converting values, matrices, etc. from one
Realtype to another. - Convenience trait that combines
SendandSync
Functions
- Constructs the background grid for marching cubes based on the parameters supplied to the surface reconstruction
- Initializes the global thread pool used by this library with the given parameters.
- Performs a marching cubes surface construction of the fluid represented by the given particle positions
- Performs a marching cubes surface construction of the fluid represented by the given particle positions, inplace
Type Aliases
- Convenience type alias for an AABB in two dimensions
- Convenience type alias for an AABB in three dimensions