pub struct GridBoundaryFaceFlags(/* private fields */);Expand description
Represents an assignment of e.g. a cell to the outer faces of a grid it touches
Implementations
Sourceimpl GridBoundaryFaceFlags
impl GridBoundaryFaceFlags
Sourcepub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> bool
Returns whether none of the face flag bits is set, i.e. it does not correspond to any face
Sourcepub fn classify_cell<I: Index, R: Real>(
grid: &UniformGrid<I, R>,
cell_index: &CellIndex<I>,
) -> Self
pub fn classify_cell<I: Index, R: Real>( grid: &UniformGrid<I, R>, cell_index: &CellIndex<I>, ) -> Self
Classifies the cell with the given index to zero or more boundary faces of the grid
Sourcepub fn classify_point<I: Index, R: Real>(
grid: &UniformGrid<I, R>,
point_index: &PointIndex<I>,
) -> Self
pub fn classify_point<I: Index, R: Real>( grid: &UniformGrid<I, R>, point_index: &PointIndex<I>, ) -> Self
Classifies the point with the given index to zero or more boundary faces of the grid
Sourcepub fn classify_local_edge(&self, local_edge_index: usize) -> Self
pub fn classify_local_edge(&self, local_edge_index: usize) -> Self
Bitwise-and combination with the face flags of a local edge of a cell
If the current face flags correspond to the boundary faces of a grid touched by a cell, this bitwise and corresponds to the grid boundaries that are touched by the given edge of that cell.
Sourcepub fn iter_individual(&self) -> impl Iterator<Item = DirectedAxis>
pub fn iter_individual(&self) -> impl Iterator<Item = DirectedAxis>
Iterator over all individual active boundary faces